# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['streamlit_lightweight_charts']

package_data = \
{'': ['*']}

install_requires = \
['streamlit>=1.27.2,<2.0.0']

setup_kwargs = {
    'name': 'streamlit-tradingview-charts',
    'version': '0.1.0',
    'description': 'Wrapper for TradingView `lightweight-charts`',
    'long_description': '# streamlit-lightweight-charts\nStreamlit wrapper for performant Tradingview\'s Financial: `lightweight-charts`\n\nThe Lightweight Charts library is the best choice to display financial data as an interactive chart on a web page without affecting loading speed and performance.\n\n- [Features Demo](https://www.tradingview.com/lightweight-charts/)\n- [Documentation](https://tradingview.github.io/lightweight-charts/)\n- [GitHub](https://github.com/tradingview/lightweight-charts)\n- [Pypi](https://pypi.org/project/streamlit-lightweight-charts/)\n\n### Versions\n- Version 0.7.19 - FIX: React build was not been commited\n- Version 0.7.20 - Example loading from CSV\n\n## How to install:\n```\npython -m pip install streamlit-lightweight-charts\n```\n\n## How to use:\n```\nfrom streamlit_lightweight_charts import renderLightweightCharts\n\nrenderLightweightCharts(charts: <List of Dicts> , key: <str>)\n```\n\n### API\n- charts: `<List of Dicts>`\n\n    - [chart](https://tradingview.github.io/lightweight-charts/docs/api/interfaces/ChartOptions): `<Dict>`\n\n    - [series](https://tradingview.github.io/lightweight-charts/docs/series-types): `<List of Dicts>`\n\n        - [type](https://tradingview.github.io/lightweight-charts/docs/series-types): `<str-enum>`\n            [ Area, Bar, Baseline, Candlestick, Histogram, Line ]\n\n        - data: `<List of Dicts>` accordingly to series type\n\n        - options: `<Dict>` with style options\n\n        - priceScale: `<Dict>` optional\n\n        - markers: `<List of Dicts>` optional\n\n- key: `<str>` when creating multiple charts in one page\n\n<br/>\n\n# e.g.:\n<br />\n\n# Overlaid Charts\n\n[![Price with Volume Chart](https://github.com/freyastreamlit/streamlit-lightweight-charts/blob/main/examples/PriceVolumeChart.png?raw=true)](https://freyastreamlit-streamlit-lightw-examplespricevolumechart-j8ldyo.streamlit.app/)\n\n### [Click for a working sample on Streamlit Cloud ⬆](https://freyastreamlit-streamlit-lightw-examplespricevolumechart-j8ldyo.streamlit.app/)\n<br />\n\n```python\nimport streamlit as st\nfrom streamlit_lightweight_charts import renderLightweightCharts\nimport streamlit_lightweight_charts.dataSamples as data\n\npriceVolumeChartOptions = {\n    "height": 400,\n    "rightPriceScale": {\n        "scaleMargins": {\n            "top": 0.2,\n            "bottom": 0.25,\n        },\n        "borderVisible": False,\n    },\n    "overlayPriceScales": {\n        "scaleMargins": {\n            "top": 0.7,\n            "bottom": 0,\n        }\n    },\n    "layout": {\n        "background": {\n            "type": \'solid\',\n            "color": \'#131722\'\n        },\n        "textColor": \'#d1d4dc\',\n    },\n    "grid": {\n        "vertLines": {\n            "color": \'rgba(42, 46, 57, 0)\',\n        },\n        "horzLines": {\n            "color": \'rgba(42, 46, 57, 0.6)\',\n        }\n    }\n}\n\npriceVolumeSeries = [\n    {\n        "type": \'Area\',\n        "data": data.priceVolumeSeriesArea,\n        "options": {\n            "topColor": \'rgba(38,198,218, 0.56)\',\n            "bottomColor": \'rgba(38,198,218, 0.04)\',\n            "lineColor": \'rgba(38,198,218, 1)\',\n            "lineWidth": 2,\n        }\n    },\n    {\n        "type": \'Histogram\',\n        "data": data.priceVolumeSeriesHistogram,\n        "options": {\n            "color": \'#26a69a\',\n            "priceFormat": {\n                "type": \'volume\',\n            },\n            "priceScaleId": "" # set as an overlay setting,\n        },\n        "priceScale": {\n            "scaleMargins": {\n                "top": 0.7,\n                "bottom": 0,\n            }\n        }\n    }\n]\nst.subheader("Price and Volume Series Chart")\n\nrenderLightweightCharts([\n    {\n        "chart": priceVolumeChartOptions,\n        "series": priceVolumeSeries\n    }\n], \'priceAndVolume\')\n```\n---\n<br />\n\n[![Overlaid Areas Chart](https://github.com/freyastreamlit/streamlit-lightweight-charts/blob/main/examples/OverlaidAreasChart.png?raw=true)](https://freyastreamlit-streamlit-ligh-examplesoverlaidareaschart-3pg5tr.streamlit.app/)\n\n### [Click for a working sample on Streamlit Cloud ⬆](https://freyastreamlit-streamlit-ligh-examplesoverlaidareaschart-3pg5tr.streamlit.app/)\n<br />\n\n```python\nimport streamlit as st\nfrom streamlit_lightweight_charts import renderLightweightCharts\nimport streamlit_lightweight_charts.dataSamples as data\n\noverlaidAreaSeriesOptions = {\n    "height": 400,\n    "rightPriceScale": {\n        "scaleMargins": {\n            "top": 0.1,\n            "bottom": 0.1,\n        },\n        "mode": 2, # PriceScaleMode: 0-Normal, 1-Logarithmic, 2-Percentage, 3-IndexedTo100\n        "borderColor": \'rgba(197, 203, 206, 0.4)\',\n    },\n    "timeScale": {\n        "borderColor": \'rgba(197, 203, 206, 0.4)\',\n    },\n    "layout": {\n        "background": {\n            "type": \'solid\',\n            "color": \'#100841\'\n        },\n        "textColor": \'#ffffff\',\n    },\n    "grid": {\n        "vertLines": {\n            "color": \'rgba(197, 203, 206, 0.4)\',\n            "style": 1, # LineStyle: 0-Solid, 1-Dotted, 2-Dashed, 3-LargeDashed\n        },\n        "horzLines": {\n            "color": \'rgba(197, 203, 206, 0.4)\',\n            "style": 1, # LineStyle: 0-Solid, 1-Dotted, 2-Dashed, 3-LargeDashed\n        }\n    }\n}\n\nseriesOverlaidChart = [\n    {\n        "type": \'Area\',\n        "data": data.seriesMultipleChartArea01,\n        "options": {\n            "topColor": \'rgba(255, 192, 0, 0.7)\',\n            "bottomColor": \'rgba(255, 192, 0, 0.3)\',\n            "lineColor": \'rgba(255, 192, 0, 1)\',\n            "lineWidth": 2,\n        },\n        "markers": [\n            {\n                "time": \'2019-04-08\',\n                "position": \'aboveBar\',\n                "color": \'rgba(255, 192, 0, 1)\',\n                "shape": \'arrowDown\',\n                "text": \'H\',\n                "size": 3\n            },\n            {\n                "time": \'2019-05-13\',\n                "position": \'belowBar\',\n                "color": \'rgba(255, 192, 0, 1)\',\n                "shape": \'arrowUp\',\n                "text": \'L\',\n                "size": 3\n            },\n        ]\n    },\n    {\n        "type": \'Area\',\n        "data": data.seriesMultipleChartArea02,\n        "options": {\n            "topColor": \'rgba(67, 83, 254, 0.7)\',\n            "bottomColor": \'rgba(67, 83, 254, 0.3)\',\n            "lineColor": \'rgba(67, 83, 254, 1)\',\n            "lineWidth": 2,\n        },\n        "markers": [\n\n            {\n                "time": \'2019-05-03\',\n                "position": \'aboveBar\',\n                "color": \'rgba(67, 83, 254, 1)\',\n                "shape": \'arrowDown\',\n                "text": \'PEAK\',\n                "size": 3\n            },\n        ]\n    }\n]\nst.subheader("Overlaid Series with Markers")\n\nrenderLightweightCharts([\n    {\n        "chart": overlaidAreaSeriesOptions,\n        "series": seriesOverlaidChart\n    }\n], \'overlaid\')\n```\n---\n\n# Streamlit integration\n\n[![Data Toggling for an Area Chart](https://github.com/freyastreamlit/streamlit-lightweight-charts/blob/main/examples/DataToggling.png?raw=true)](https://freyastreamlit-streamlit-lightweigh-examplesdatatoggling-cbni35.streamlit.app/)\n\n### [Click for a working sample on Streamlit Cloud ⬆](https://freyastreamlit-streamlit-lightweigh-examplesdatatoggling-cbni35.streamlit.app/)\n<br />\n\n```python\nimport streamlit as st\nfrom streamlit_lightweight_charts import renderLightweightCharts\nimport streamlit_lightweight_charts.dataSamples as data\n\nchartOptions = {\n    "layout": {\n        "textColor": \'black\',\n        "background": {\n            "type": \'solid\',\n            "color": \'white\'\n        }\n    }\n}\n\nst.subheader("Data Toggling for an Area Chart")\n\ndata_select = st.sidebar.radio(\'Select data source:\', (\'Area 01\', \'Area 02\'))\n\nif data_select == \'Area 01\':\n    renderLightweightCharts( [\n        {\n            "chart": chartOptions,\n            "series": [{\n                "type": \'Area\',\n                "data": data.seriesMultipleChartArea01,\n                "options": {}\n            }],\n        }\n    ], \'area\')\nelse:\n    renderLightweightCharts( [\n        {\n            "chart": chartOptions,\n            "series": [{\n                "type": \'Area\',\n                "data": data.seriesMultipleChartArea02,\n                "options": {}\n            }],\n        }\n    ], \'area\')\n```\n---\n<br />\n\n![Multi Pane Chart with Pandas](https://github.com/freyastreamlit/streamlit-lightweight-charts/blob/main/examples/MultiPaneChartsWithPandas.png?raw=true)\n\n```python\nimport streamlit as st\nfrom streamlit_lightweight_charts import renderLightweightCharts\n\nimport json\nimport numpy as np\nimport yfinance as yf\nimport pandas as pd\nimport pandas_ta as ta\n\nCOLOR_BULL = \'rgba(38,166,154,0.9)\' # #26a69a\nCOLOR_BEAR = \'rgba(239,83,80,0.9)\'  # #ef5350\n\n# Request historic pricing data via finance.yahoo.com API\ndf = yf.Ticker(\'AAPL\').history(period=\'4mo\')[[\'Open\', \'High\', \'Low\', \'Close\', \'Volume\']]\n\n# Some data wrangling to match required format\ndf = df.reset_index()\ndf.columns = [\'time\',\'open\',\'high\',\'low\',\'close\',\'volume\']                  # rename columns\ndf[\'time\'] = df[\'time\'].dt.strftime(\'%Y-%m-%d\')                             # Date to string\ndf[\'color\'] = np.where(  df[\'open\'] > df[\'close\'], COLOR_BEAR, COLOR_BULL)  # bull or bear\ndf.ta.macd(close=\'close\', fast=6, slow=12, signal=5, append=True)           # calculate macd\n\n# export to JSON format\ncandles = json.loads(df.to_json(orient = "records"))\nvolume = json.loads(df.rename(columns={"volume": "value",}).to_json(orient = "records"))\nmacd_fast = json.loads(df.rename(columns={"MACDh_6_12_5": "value"}).to_json(orient = "records"))\nmacd_slow = json.loads(df.rename(columns={"MACDs_6_12_5": "value"}).to_json(orient = "records"))\ndf[\'color\'] = np.where(  df[\'MACD_6_12_5\'] > 0, COLOR_BULL, COLOR_BEAR)  # MACD histogram color\nmacd_hist = json.loads(df.rename(columns={"MACD_6_12_5": "value"}).to_json(orient = "records"))\n\n\nchartMultipaneOptions = [\n    {\n        "width": 600,\n        "height": 400,\n        "layout": {\n            "background": {\n                "type": "solid",\n                "color": \'white\'\n            },\n            "textColor": "black"\n        },\n        "grid": {\n            "vertLines": {\n                "color": "rgba(197, 203, 206, 0.5)"\n                },\n            "horzLines": {\n                "color": "rgba(197, 203, 206, 0.5)"\n            }\n        },\n        "crosshair": {\n            "mode": 0\n        },\n        "priceScale": {\n            "borderColor": "rgba(197, 203, 206, 0.8)"\n        },\n        "timeScale": {\n            "borderColor": "rgba(197, 203, 206, 0.8)",\n            "barSpacing": 15\n        },\n        "watermark": {\n            "visible": True,\n            "fontSize": 48,\n            "horzAlign": \'center\',\n            "vertAlign": \'center\',\n            "color": \'rgba(171, 71, 188, 0.3)\',\n            "text": \'AAPL - D1\',\n        }\n    },\n    {\n        "width": 600,\n        "height": 100,\n        "layout": {\n            "background": {\n                "type": \'solid\',\n                "color": \'transparent\'\n            },\n            "textColor": \'black\',\n        },\n        "grid": {\n            "vertLines": {\n                "color": \'rgba(42, 46, 57, 0)\',\n            },\n            "horzLines": {\n                "color": \'rgba(42, 46, 57, 0.6)\',\n            }\n        },\n        "timeScale": {\n            "visible": False,\n        },\n        "watermark": {\n            "visible": True,\n            "fontSize": 18,\n            "horzAlign": \'left\',\n            "vertAlign": \'top\',\n            "color": \'rgba(171, 71, 188, 0.7)\',\n            "text": \'Volume\',\n        }\n    },\n    {\n        "width": 600,\n        "height": 200,\n        "layout": {\n            "background": {\n                "type": "solid",\n                "color": \'white\'\n            },\n            "textColor": "black"\n        },\n        "timeScale": {\n            "visible": False,\n        },\n        "watermark": {\n            "visible": True,\n            "fontSize": 18,\n            "horzAlign": \'left\',\n            "vertAlign": \'center\',\n            "color": \'rgba(171, 71, 188, 0.7)\',\n            "text": \'MACD\',\n        }\n    }\n]\n\nseriesCandlestickChart = [\n    {\n        "type": \'Candlestick\',\n        "data": candles,\n        "options": {\n            "upColor": COLOR_BULL,\n            "downColor": COLOR_BEAR,\n            "borderVisible": False,\n            "wickUpColor": COLOR_BULL,\n            "wickDownColor": COLOR_BEAR\n        }\n    }\n]\n\nseriesVolumeChart = [\n    {\n        "type": \'Histogram\',\n        "data": volume,\n        "options": {\n            "priceFormat": {\n                "type": \'volume\',\n            },\n            "priceScaleId": "" # set as an overlay setting,\n        },\n        "priceScale": {\n            "scaleMargins": {\n                "top": 0,\n                "bottom": 0,\n            },\n            "alignLabels": False\n        }\n    }\n]\n\nseriesMACDchart = [\n    {\n        "type": \'Line\',\n        "data": macd_fast,\n        "options": {\n            "color": \'blue\',\n            "lineWidth": 2\n        }\n    },\n    {\n        "type": \'Line\',\n        "data": macd_slow,\n        "options": {\n            "color": \'green\',\n            "lineWidth": 2\n        }\n    },\n    {\n        "type": \'Histogram\',\n        "data": macd_hist,\n        "options": {\n            "color": \'red\',\n            "lineWidth": 1\n        }\n    }\n]\n\nst.subheader("Multipane Chart with Pandas")\n\nrenderLightweightCharts([\n    {\n        "chart": chartMultipaneOptions[0],\n        "series": seriesCandlestickChart\n    },\n    {\n        "chart": chartMultipaneOptions[1],\n        "series": seriesVolumeChart\n    },\n    {\n        "chart": chartMultipaneOptions[2],\n        "series": seriesMACDchart\n    }\n], \'multipane\')\n```\n---\n<br />\n\n![Multi Pane Chart (intraday) from CSV)](https://github.com/freyastreamlit/streamlit-lightweight-charts/blob/main/examples/MultiPaneChartsFromCSV.png?raw=true)\n\n```python\nimport streamlit as st\nfrom streamlit_lightweight_charts import renderLightweightCharts\n\nimport json\nimport numpy as np\nimport pandas as pd\n\nCOLOR_BULL = \'rgba(38,166,154,0.9)\' # #26a69a\nCOLOR_BEAR = \'rgba(239,83,80,0.9)\'  # #ef5350\n\nCSVFILE = \'https://github.com/freyastreamlit/streamlit-lightweight-charts/blob/main/examples/MultiPaneChartsFromCSV.csv?raw=true\'\n\ndf = pd.read_csv(CSVFILE, skiprows=0, parse_dates=[\'datetime\'], skip_blank_lines=True)\n\ndf[\'time\'] = df[\'datetime\'].view(\'int64\') // 10**9  # We will use time in UNIX timestamp\ndf[\'color\'] = np.where(  df[\'open\'] > df[\'close\'], COLOR_BEAR, COLOR_BULL)  # bull or bear\n\n# export to JSON format\ncandles = json.loads(\n    df.filter([\'time\',\'open\',\'high\',\'low\',\'close\'], axis=1)\n      .to_json(orient = "records") )\n\nvolume = json.loads(\n    df.filter([\'time\',\'volume\'], axis=1)\n      .rename(columns={"volume": "value",})\n      .to_json(orient = "records") )\n\nmacd_fast = json.loads(\n    df.filter([\'time\',\'macd_fast\'], axis=1)\n      .rename(columns={"macd_fast": "value"})\n      .to_json(orient = "records"))\n\nmacd_slow = json.loads(\n    df.filter([\'time\',\'macd_slow\'], axis=1)\n      .rename(columns={"macd_slow": "value"})\n      .to_json(orient = "records"))\n\ndf[\'color\'] = np.where(  df[\'macd_hist\'] > 0, COLOR_BULL, COLOR_BEAR)  # MACD histogram color\nmacd_hist = json.loads(\n    df.filter([\'time\',\'macd_hist\'], axis=1)\n      .rename(columns={"macd_hist": "value"})\n      .to_json(orient = "records"))\n\nchartMultipaneOptions = [\n    {\n        "width": 600,\n        "height": 400,\n        "layout": {\n            "background": {\n                "type": "solid",\n                "color": \'white\'\n            },\n            "textColor": "black"\n        },\n        "grid": {\n            "vertLines": {\n                "color": "rgba(197, 203, 206, 0.5)"\n                },\n            "horzLines": {\n                "color": "rgba(197, 203, 206, 0.5)"\n            }\n        },\n        "crosshair": {\n            "mode": 0\n        },\n        "priceScale": {\n            "borderColor": "rgba(197, 203, 206, 0.8)"\n        },\n        "timeScale": {\n            "borderColor": "rgba(197, 203, 206, 0.8)",\n            "barSpacing": 10,\n            "minBarSpacing": 8,\n            "timeVisible": True,\n            "secondsVisible": False,\n        },\n        "watermark": {\n            "visible": True,\n            "fontSize": 48,\n            "horzAlign": \'center\',\n            "vertAlign": \'center\',\n            "color": \'rgba(171, 71, 188, 0.3)\',\n            "text": \'Intraday\',\n        }\n    },\n    {\n        "width": 600,\n        "height": 100,\n        "layout": {\n            "background": {\n                "type": \'solid\',\n                "color": \'transparent\'\n            },\n            "textColor": \'black\',\n        },\n        "grid": {\n            "vertLines": {\n                "color": \'rgba(42, 46, 57, 0)\',\n            },\n            "horzLines": {\n                "color": \'rgba(42, 46, 57, 0.6)\',\n            }\n        },\n        "timeScale": {\n            "visible": False,\n        },\n        "watermark": {\n            "visible": True,\n            "fontSize": 18,\n            "horzAlign": \'left\',\n            "vertAlign": \'top\',\n            "color": \'rgba(171, 71, 188, 0.7)\',\n            "text": \'Volume\',\n        }\n    },\n    {\n        "width": 600,\n        "height": 200,\n        "layout": {\n            "background": {\n                "type": "solid",\n                "color": \'white\'\n            },\n            "textColor": "black"\n        },\n        "timeScale": {\n            "visible": False,\n        },\n        "watermark": {\n            "visible": True,\n            "fontSize": 18,\n            "horzAlign": \'left\',\n            "vertAlign": \'center\',\n            "color": \'rgba(171, 71, 188, 0.7)\',\n            "text": \'MACD\',\n        }\n    }\n]\n\nseriesCandlestickChart = [\n    {\n        "type": \'Candlestick\',\n        "data": candles,\n        "options": {\n            "upColor": COLOR_BULL,\n            "downColor": COLOR_BEAR,\n            "borderVisible": False,\n            "wickUpColor": COLOR_BULL,\n            "wickDownColor": COLOR_BEAR\n        }\n    }\n]\n\nseriesVolumeChart = [\n    {\n        "type": \'Histogram\',\n        "data": volume,\n        "options": {\n            "priceFormat": {\n                "type": \'volume\',\n            },\n            "priceScaleId": "" # set as an overlay setting,\n        },\n        "priceScale": {\n            "scaleMargins": {\n                "top": 0,\n                "bottom": 0,\n            },\n            "alignLabels": False\n        }\n    }\n]\n\nseriesMACDchart = [\n    {\n        "type": \'Line\',\n        "data": macd_fast,\n        "options": {\n            "color": \'blue\',\n            "lineWidth": 2\n        }\n    },\n    {\n        "type": \'Line\',\n        "data": macd_slow,\n        "options": {\n            "color": \'green\',\n            "lineWidth": 2\n        }\n    },\n    {\n        "type": \'Histogram\',\n        "data": macd_hist,\n        "options": {\n            # "color": \'red\',\n            "lineWidth": 1\n        }\n    }\n]\n\nst.subheader("Multipane Chart (intraday) from CSV")\n\nrenderLightweightCharts([\n    {\n        "chart": chartMultipaneOptions[0],\n        "series": seriesCandlestickChart\n    },\n    {\n        "chart": chartMultipaneOptions[1],\n        "series": seriesVolumeChart\n    },\n    {\n        "chart": chartMultipaneOptions[2],\n        "series": seriesMACDchart\n    }\n], \'multipane\')\n```\n---\n<br />\n\n# Basic charts\n\n![Line Chart](https://github.com/freyastreamlit/streamlit-lightweight-charts/blob/main/examples/LineChart.png?raw=true)\n\n```python\nimport streamlit as st\nfrom streamlit_lightweight_charts import renderLightweightCharts\n\nchartOptions = {\n    "layout": {\n        "textColor": \'black\',\n        "background": {\n            "type": \'solid\',\n            "color": \'white\'\n        }\n    }\n}\n\nseriesLineChart = [{\n    "type": \'Line\',\n    "data": [\n        { "time": \'2018-12-22\', "value": 32.51 },\n        { "time": \'2018-12-23\', "value": 31.11 },\n        { "time": \'2018-12-24\', "value": 27.02 },\n        { "time": \'2018-12-25\', "value": 27.32 },\n        { "time": \'2018-12-26\', "value": 25.17 },\n        { "time": \'2018-12-27\', "value": 28.89 },\n        { "time": \'2018-12-28\', "value": 25.46 },\n        { "time": \'2018-12-29\', "value": 23.92 },\n        { "time": \'2018-12-30\', "value": 22.68 },\n        { "time": \'2018-12-31\', "value": 22.67 },\n    ],\n    "options": {}\n}]\n\nst.subheader("Line Chart with Watermark")\n\nrenderLightweightCharts([\n    {\n        "chart": chartOptions,\n        "series": seriesLineChart\n    }\n], \'line\')\n```\n---\n<br />\n\n![Area Chart](https://github.com/freyastreamlit/streamlit-lightweight-charts/blob/main/examples/AreaChart.png?raw=true)\n\n```python\nimport streamlit as st\nfrom streamlit_lightweight_charts import renderLightweightCharts\n\nchartOptions = {\n    "layout": {\n        "textColor": \'black\',\n        "background": {\n            "type": \'solid\',\n            "color": \'white\'\n        }\n    }\n}\n\nseriesAreaChart = [{\n    "type": \'Area\',\n    "data": [\n        { "time": \'2018-12-22\', "value": 32.51 },\n        { "time": \'2018-12-23\', "value": 31.11 },\n        { "time": \'2018-12-24\', "value": 27.02 },\n        { "time": \'2018-12-25\', "value": 27.32 },\n        { "time": \'2018-12-26\', "value": 25.17 },\n        { "time": \'2018-12-27\', "value": 28.89 },\n        { "time": \'2018-12-28\', "value": 25.46 },\n        { "time": \'2018-12-29\', "value": 23.92 },\n        { "time": \'2018-12-30\', "value": 22.68 },\n        { "time": \'2018-12-31\', "value": 22.67 },\n    ],\n    "options": {}\n}]\n\nst.subheader("Area Chart with Watermark")\nrenderLightweightCharts( [\n    {\n        "chart": chartOptions,\n        "series": seriesAreaChart,\n    }\n], \'area\')\n```\n---\n<br />\n\n![Histogram Chart](https://github.com/freyastreamlit/streamlit-lightweight-charts/blob/main/examples/HistogramChart.png?raw=true)\n\n```python\nimport streamlit as st\nfrom streamlit_lightweight_charts import renderLightweightCharts\n\nchartOptions = {\n    "layout": {\n        "textColor": \'black\',\n        "background": {\n            "type": \'solid\',\n            "color": \'white\'\n        }\n    }\n}\n\nseriesHistogramChart = [{\n    "type": \'Histogram\',\n    "data": [\n        { "value": 1, "time": 1642425322 },\n        { "value": 8, "time": 1642511722 },\n        { "value": 10, "time": 1642598122 },\n        { "value": 20, "time": 1642684522 },\n        { "value": 3, "time": 1642770922, "color": \'red\' },\n        { "value": 43, "time": 1642857322 },\n        { "value": 41, "time": 1642943722, "color": \'red\' },\n        { "value": 43, "time": 1643030122 },\n        { "value": 56, "time": 1643116522 },\n        { "value": 46, "time": 1643202922, "color": \'red\' }\n    ],\n    "options": { "color": \'#26a69a\' }\n}]\n\nst.subheader("Histogram Chart with Watermark")\n\nrenderLightweightCharts([\n    {\n        "chart": chartOptions,\n        "series": seriesHistogramChart\n    }\n], \'histogram\')\n```\n---\n<br />\n\n![Bar Chart](https://github.com/freyastreamlit/streamlit-lightweight-charts/blob/main/examples/BarChart.png?raw=true)\n\n```python\nimport streamlit as st\nfrom streamlit_lightweight_charts import renderLightweightCharts\n\nchartOptions = {\n    "layout": {\n        "textColor": \'black\',\n        "background": {\n            "type": \'solid\',\n            "color": \'white\'\n        }\n    }\n}\n\nseriesBarChart = [{\n    "type": \'Bar\',\n    "data": [\n        { "open": 10, "high": 10.63, "low": 9.49, "close": 9.55, "time": 1642427876 },\n        { "open": 9.55, "high": 10.30, "low": 9.42, "close": 9.94, "time": 1642514276 },\n        { "open": 9.94, "high": 10.17, "low": 9.92, "close": 9.78, "time": 1642600676 },\n        { "open": 9.78, "high": 10.59, "low": 9.18, "close": 9.51, "time": 1642687076 },\n        { "open": 9.51, "high": 10.46, "low": 9.10, "close": 10.17, "time": 1642773476 },\n        { "open": 10.17, "high": 10.96, "low": 10.16, "close": 10.47, "time": 1642859876 },\n        { "open": 10.47, "high": 11.39, "low": 10.40, "close": 10.81, "time": 1642946276 },\n        { "open": 10.81, "high": 11.60, "low": 10.30, "close": 10.75, "time": 1643032676 },\n        { "open": 10.75, "high": 11.60, "low": 10.49, "close": 10.93, "time": 1643119076 },\n        { "open": 10.93, "high": 11.53, "low": 10.76, "close": 10.96, "time": 1643205476 }\n    ],\n    "options": {\n        "upColor": \'#26a69a\',\n        "downColor": \'#ef5350\'\n    }\n}]\n\nst.subheader("Bar Chart with Watermark")\nrenderLightweightCharts([\n    {\n        "chart": chartOptions,\n        "series": seriesBarChart\n    }\n], \'bar\')\n```\n---\n<br />\n\n![Candlestick Chart](https://github.com/freyastreamlit/streamlit-lightweight-charts/blob/main/examples/CandlestickChart.png?raw=true)\n\n```python\nimport streamlit as st\nfrom streamlit_lightweight_charts import renderLightweightCharts\n\nchartOptions = {\n    "layout": {\n        "textColor": \'black\',\n        "background": {\n            "type": \'solid\',\n            "color": \'white\'\n        }\n    }\n}\n\nseriesCandlestickChart = [{\n    "type": \'Candlestick\',\n    "data": [\n        { "open": 10, "high": 10.63, "low": 9.49, "close": 9.55, "time": 1642427876 },\n        { "open": 9.55, "high": 10.30, "low": 9.42, "close": 9.94, "time": 1642514276 },\n        { "open": 9.94, "high": 10.17, "low": 9.92, "close": 9.78, "time": 1642600676 },\n        { "open": 9.78, "high": 10.59, "low": 9.18, "close": 9.51, "time": 1642687076 },\n        { "open": 9.51, "high": 10.46, "low": 9.10, "close": 10.17, "time": 1642773476 },\n        { "open": 10.17, "high": 10.96, "low": 10.16, "close": 10.47, "time": 1642859876 },\n        { "open": 10.47, "high": 11.39, "low": 10.40, "close": 10.81, "time": 1642946276 },\n        { "open": 10.81, "high": 11.60, "low": 10.30, "close": 10.75, "time": 1643032676 },\n        { "open": 10.75, "high": 11.60, "low": 10.49, "close": 10.93, "time": 1643119076 },\n        { "open": 10.93, "high": 11.53, "low": 10.76, "close": 10.96, "time": 1643205476 }\n    ],\n    "options": {\n        "upColor": \'#26a69a\',\n        "downColor": \'#ef5350\',\n        "borderVisible": False,\n        "wickUpColor": \'#26a69a\',\n        "wickDownColor": \'#ef5350\'\n    }\n}]\n\nst.subheader("Candlestick Chart with Watermark")\n\nrenderLightweightCharts([\n    {\n        "chart": chartOptions,\n        "series": seriesCandlestickChart\n    }\n], \'candlestick\')\n```\n---\n<br />\n\n![Baseline Chart](https://github.com/freyastreamlit/streamlit-lightweight-charts/blob/main/examples/BaselineChart.png?raw=true)\n\n```python\nimport streamlit as st\nfrom streamlit_lightweight_charts import renderLightweightCharts\n\nchartOptions = {\n    "layout": {\n        "textColor": \'black\',\n        "background": {\n            "type": \'solid\',\n            "color": \'white\'\n        }\n    }\n}\n\nseriesBaselineChart = [{\n    "type": \'Baseline\',\n    "data": [\n        { "value": 1, "time": 1642425322 },\n        { "value": 8, "time": 1642511722 },\n        { "value": 10, "time": 1642598122 },\n        { "value": 20, "time": 1642684522 },\n        { "value": 3, "time": 1642770922 },\n        { "value": 43, "time": 1642857322 },\n        { "value": 41, "time": 1642943722 },\n        { "value": 43, "time": 1643030122 },\n        { "value": 56, "time": 1643116522 },\n        { "value": 46, "time": 1643202922 }\n    ],\n    "options": {\n        "baseValue": { "type": "price", "price": 25 },\n        "topLineColor": \'rgba( 38, 166, 154, 1)\',\n        "topFillColor1": \'rgba( 38, 166, 154, 0.28)\',\n        "topFillColor2": \'rgba( 38, 166, 154, 0.05)\',\n        "bottomLineColor": \'rgba( 239, 83, 80, 1)\',\n        "bottomFillColor1": \'rgba( 239, 83, 80, 0.05)\',\n        "bottomFillColor2": \'rgba( 239, 83, 80, 0.28)\'\n    }\n}]\n\nst.subheader("Baseline Chart with Watermark")\n\nrenderLightweightCharts([\n    {\n        "chart": chartOptions,\n        "series": seriesBaselineChart\n    }\n], \'baseline\')\n```\n',
    'author': 'Loki Arya',
    'author_email': 'loki.arya+osdev@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/lokiarya/streamlit-lightweight-charts',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
